==> ejc-proequipmentcorp-impl-3.0.0-20221017.101726-8-sources.jar: com/ejianc/business/proequipmentcorprent/order/service/impl/RentOrderBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorprent.order.service.impl;

import com.ejianc.business.proequipmentcorprent.order.bean.RentOrderEntity;
import com.ejianc.business.proequipmentcorprent.order.service.IRentOrderService;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.BillStateEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

@Service("rentOrder") 
public class RentOrderBpmServiceImpl implements ICommonBusinessService {
	private final Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    private IBillTypeApi billTypeApi;

	@Autowired
	private IRentOrderService rentOrderService;

// 订单接收：/ejc-supbusiness-web/openapi/equipmentOrder/saveOrUpdate
//订单关闭：/ejc-supbusiness-web/openapi/equipmentOrder/updateOrderCloseFlag
//订单撤回：/ejc-supbusiness-web/openapi/equipmentOrder/deleteOrder
	private final String DEL_BILL_SERVER_URL = "/ejc-supbusiness-web/openapi/equipmentOrder/deleteOrder";

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		orderEntity.setCommitId(InvocationInfoProxy.getUserid());
		rentOrderService.saveOrUpdate(orderEntity,false);
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		//推送供方 TODO  待修改
//		Boolean pushFlag = rentOrderService.pushBillToSupCenter(orderEntity,billTypeCode);
//		logger.info("获取推送供方结果--"+pushFlag);
//		if(pushFlag){
//			//推送成功后处理逻辑
//			if(BillStateEnum.COMMITED_STATE.getBillStateCode() == state){
//				orderEntity.setCommitId(InvocationInfoProxy.getUserid());
//			}
//			orderEntity.setReceiveState(0);
//			rentOrderService.saveOrUpdate(orderEntity,false);
//		}else{
//			return CommonResponse.error("推送供方失败");
//		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		if(orderEntity.getReceiveState()==0){
			return CommonResponse.success();
		}else{
			return CommonResponse.error("该订单已被下游操作，不允许回退!");
		}
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
//		TODO  待修改
//		return rentOrderService.updatePushBill(orderEntity,billTypeCode,DEL_BILL_SERVER_URL);
		return CommonResponse.success();
	}

}

==> ejc-proequipmentcorp-impl-3.0.0-20221220.151353-256-sources.jar: com/ejianc/business/proequipmentcorprent/order/service/impl/RentOrderBpmServiceImpl.java <==
package com.ejianc.business.proequipmentcorprent.order.service.impl;

import com.ejianc.business.proequipmentcorprent.order.bean.RentOrderEntity;
import com.ejianc.business.proequipmentcorprent.order.service.IRentOrderService;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.response.BillStateEnum;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.springframework.beans.factory.annotation.Autowired;

@Service("rentOrder") 
public class RentOrderBpmServiceImpl implements ICommonBusinessService {
	private final Logger logger = LoggerFactory.getLogger(getClass());
    @Autowired
    private IBillTypeApi billTypeApi;

	@Autowired
	private IRentOrderService rentOrderService;

// 订单接收：/ejc-supbusiness-web/openapi/corpRentOrder/saveOrUpdate
//订单关闭：/ejc-supbusiness-web/openapi/corpRentOrder/updateOrderCloseFlag
//订单撤回：/ejc-supbusiness-web/openapi/corpRentOrder/deleteOrder
	private final String DEL_BILL_SERVER_URL = "/ejc-supbusiness-web/openapi/corpRentOrder/deleteOrder";

	/**
	 * 提交前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeSubmitProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	};

	/**
	 * 提交完回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterSubmitProcessor(Long billId, Integer state, String billTypeCode){
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		orderEntity.setCommitId(InvocationInfoProxy.getUserid());
		rentOrderService.saveOrUpdate(orderEntity,false);
		return CommonResponse.success();
	}

	/**
	 * 有审批流的撤回前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeHasBpmBack(Long billId, Integer state, String billTypeCode) {

		return CommonResponse.success();
	};

	/**
	 * 有审批流的撤回后回调
	 *
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterHasBpmBack(Long billId, Integer state, String billTypeCode){
		return CommonResponse.success();
	};

	/**
	 * 审批节点审批中时节点审批前回调
	 *
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeInApprovalBack(Long billId, Integer state, String billTypeCode, String sign) {
		return CommonResponse.success();
	};

	/**
	 * 终审审核前回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		//TODO
		return CommonResponse.success();
	}

	/**
	 * 终审审核完回调
	 * 
	 * @param
	 * @return
	 */
	@Override
	public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		//推送供方
		Boolean pushFlag = rentOrderService.pushBillToSupCenter(orderEntity,billTypeCode);
		logger.info("获取推送供方结果--"+pushFlag);
		if(pushFlag){
			//推送成功后处理逻辑
			if(BillStateEnum.COMMITED_STATE.getBillStateCode() == state){
				orderEntity.setCommitId(InvocationInfoProxy.getUserid());
			}
			orderEntity.setReceiveState(0);
			rentOrderService.saveOrUpdate(orderEntity,false);
		}else{
			return CommonResponse.error("推送供方失败");
		}
		return CommonResponse.success();
	}

	/**
	 * 弃审前事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		if(orderEntity.getReceiveState()==0){
			return CommonResponse.success();
		}else{
			return CommonResponse.error("该订单已被下游操作，不允许回退!");
		}
	}

	/**
	 * 弃审后事件回调
	 * 
	 * @param billId
	 * @param state
	 * @return
	 */
	@Override
	public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state, String billTypeCode) {
		RentOrderEntity orderEntity = rentOrderService.selectById(billId);
		return rentOrderService.updatePushBill(orderEntity,billTypeCode,DEL_BILL_SERVER_URL);
	}

}
